@@ -180,6 +180,10 @@ class IndexDict(IndexStruct):
     nodes_dict: Dict[int, Node] = field(default_factory=dict)
     id_map: Dict[str, int] = field(default_factory=dict)
 
+    # TODO: temporary hack to store embeddings for simple vector index
+    # this should be empty for all other indices
+    embeddings_dict: Dict[str, List[float]] = field(default_factory=dict)
+
     def add_node(
         self,
         node: Node,
@@ -237,6 +241,11 @@ class IndexDict(IndexStruct):
         """Get type."""
         return "dict"
 
+    @classmethod
+    def get_types(cls) -> List[str]:
+        """Get type."""
+        return ["dict", "simple_dict", "weaviate", "pinecone", "qdrant", "chroma"]
+
 
 @dataclass
 class KG(IndexStruct):
@@ -247,6 +256,11 @@ class KG(IndexStruct):
     table: Dict[str, Set[str]] = field(default_factory=dict)
     text_chunks: Dict[str, Node] = field(default_factory=dict)
     rel_map: Dict[str, List[Tuple[str, str]]] = field(default_factory=dict)
+    embedding_dict: Dict[str, List[float]] = field(default_factory=dict)
+
+    def add_to_embedding_dict(self, triplet_str: str, embedding: List[float]) -> None:
+        """Add embedding to dict."""
+        self.embedding_dict[triplet_str] = embedding
 
     def upsert_triplet(self, triplet: Tuple[str, str, str], node: Node) -> None:
         """Upsert a knowledge triplet to the graph."""
