@@ -1,9 +1,13 @@
 """Utilities for GPT indices."""
+import logging
 import re
 from typing import Dict, List, Optional, Set
 
 from gpt_index.data_structs.data_structs import Node
-from gpt_index.utils import globals_helper
+from gpt_index.utils import globals_helper, truncate_text
+from gpt_index.vector_stores.types import VectorStoreQueryResult
+
+_logger = logging.getLogger(__name__)
 
 
 def get_sorted_node_list(node_dict: Dict[int, Node]) -> List[Node]:
@@ -37,6 +41,20 @@ def expand_tokens_with_subtokens(tokens: Set[str]) -> Set[str]:
     return results
 
 
-def truncate_text(text: str, max_length: int) -> str:
-    """Truncate text to a maximum length."""
-    return text[: max_length - 3] + "..."
+def log_vector_store_query_result(
+    result: VectorStoreQueryResult, logger: Optional[logging.Logger] = None
+) -> None:
+    """Log vector store query result."""
+    logger = logger or _logger
+
+    assert result.ids is not None
+    assert result.nodes is not None
+    similarities = result.similarities or [1.0 for _ in result.ids]
+
+    fmt_txts = []
+    for node_idx, node_similarity, node in zip(result.ids, similarities, result.nodes):
+        fmt_txt = f"> [Node {node_idx}] [Similarity score: \
+            {float(node_similarity):.6}] {truncate_text(node.get_text(), 100)}"
+        fmt_txts.append(fmt_txt)
+    top_k_node_text = "\n".join(fmt_txts)
+    logger.debug(f"> Top {len(result.nodes)} nodes:\n{top_k_node_text}")
