@@ -2,18 +2,16 @@
 
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import Any, Dict, List, Optional, Tuple, cast
+from typing import Any, Dict, List, Tuple, cast
 from unittest.mock import patch
 
 import pytest
 
 from gpt_index.data_structs.data_structs import Node
 from gpt_index.indices.list.base import GPTListIndex
-from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.query.list.embedding_query import GPTListIndexEmbeddingQuery
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
-from gpt_index.prompts.base import Prompt
 from gpt_index.readers.schema.base import Document
 from gpt_index.utils import globals_helper
 from tests.mock_utils.mock_decorator import patch_common
@@ -216,44 +214,32 @@ def test_index_overlap(
         )
     ]
 
-    def _mock_text_splitter_with_space(
-        prompt: Prompt, num_chunks: int, padding: Optional[int] = 1
-    ) -> TokenTextSplitter:
-        """Mock text splitter."""
-        return TokenTextSplitter(
-            separator=" ",
-            chunk_size=30,
-            chunk_overlap=10,
-            tokenizer=globals_helper.tokenizer,
-        )
+    # A text splitter for test purposes
+    _text_splitter = TokenTextSplitter(
+        separator=" ",
+        chunk_size=30,
+        chunk_overlap=10,
+        tokenizer=globals_helper.tokenizer,
+    )
 
-    with patch.object(
-        PromptHelper,
-        "get_text_splitter_given_prompt",
-        side_effect=_mock_text_splitter_with_space,
-    ):
-        index = GPTListIndex(documents, **index_kwargs)
+    index = GPTListIndex(documents, text_splitter=_text_splitter, **index_kwargs)
 
-        query_str = "What is?"
-        response = index.query(query_str, mode="default", **query_kwargs)
-        node_info_0 = (
-            response.source_nodes[0].node_info
-            if response.source_nodes[0].node_info
-            else {}
-        )
-        # First chunk: 'Hello world. This is a test 1. This is a test 2.
-        # This is a test 3. This is a test 4. This is a'
-        assert node_info_0["start"] == 0  # start at the start
-        assert node_info_0["end"] == 94  # Length of first chunk.
+    query_str = "What is?"
+    response = index.query(query_str, mode="default", **query_kwargs)
+    node_info_0 = (
+        response.source_nodes[0].node_info if response.source_nodes[0].node_info else {}
+    )
+    # First chunk: 'Hello world. This is a test 1. This is a test 2.
+    # This is a test 3. This is a test 4. This is a'
+    assert node_info_0["start"] == 0  # start at the start
+    assert node_info_0["end"] == 94  # Length of first chunk.
 
-        node_info_1 = (
-            response.source_nodes[1].node_info
-            if response.source_nodes[1].node_info
-            else {}
-        )
-        # Second chunk: 'This is a test 4. This is a test 5.\n'
-        assert node_info_1["start"] == 67  # Position of second chunk relative to start
-        assert node_info_1["end"] == 103  # End index
+    node_info_1 = (
+        response.source_nodes[1].node_info if response.source_nodes[1].node_info else {}
+    )
+    # Second chunk: 'This is a test 4. This is a test 5.\n'
+    assert node_info_1["start"] == 67  # Position of second chunk relative to start
+    assert node_info_1["end"] == 103  # End index
 
 
 @patch_common
