@@ -4,6 +4,7 @@ from typing import List
 from gpt_index.data_structs.data_structs import Node
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.prompts.base import Prompt
+from tests.mock_utils.mock_utils import mock_tokenizer
 
 
 class TestPrompt(Prompt):
@@ -12,17 +13,6 @@ class TestPrompt(Prompt):
     input_variables: List[str] = ["text"]
 
 
-def mock_tokenizer(text: str) -> List[str]:
-    """Mock tokenizer."""
-    tokens = text.split(" ")
-    result = []
-    for token in tokens:
-        if token.strip() == "":
-            continue
-        result.append(token.strip())
-    return result
-
-
 def test_get_chunk_size() -> None:
     """Test get chunk size given prompt."""
     # test with 1 chunk
@@ -77,6 +67,7 @@ def test_get_text_splitter() -> None:
     text_splitter = prompt_helper.get_text_splitter_given_prompt(
         test_prompt, 2, padding=1
     )
+    assert text_splitter._chunk_size == 2
     test_text = "Hello world foo Hello world bar"
     text_chunks = text_splitter.split_text(test_text)
     assert text_chunks == ["Hello world", "foo Hello", "world bar"]
